@@ -3,7 +3,7 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.61';
+our $VERSION = '1.62';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
@@ -237,7 +237,7 @@ sub parse_datetime {
     my $dt = try { DateTime->$constructor($args) };
     $self->_our_croak('Parsed values did not produce a valid date')
         unless $dt;
-    return unless $self->_check_dt( $dt, \%args );
+    return unless $dt && $self->_check_dt( $dt, \%args );
 
     $dt->set_time_zone( $self->{time_zone} )
         if $self->{time_zone};
@@ -1008,7 +1008,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.61
+version 1.62
 
 =head1 SYNOPSIS
 
